@@ -89,7 +89,7 @@ enum mode_type { MODE_NORMAL = 0, MODE_PAN, MODE_ZOOM, MODE_ROTATE, MODE_BLUR, M
 };
 
 enum bgmode_type { BG_MODE_NONE = 0, BG_MODE_TILE, BG_MODE_CENTER,
-	BG_MODE_SEAMLESS, BG_MODE_SCALE, BG_MODE_FILL
+	BG_MODE_SCALE, BG_MODE_FILL, BG_MODE_MAX
 };
 
 enum slide_change { SLIDE_NEXT, SLIDE_PREV, SLIDE_RAND, SLIDE_FIRST, SLIDE_LAST,
@@ -120,7 +120,6 @@ void show_mini_usage(void);
 void slideshow_change_image(winwidget winwid, int change);
 void slideshow_pause_toggle(winwidget w);
 char *slideshow_create_name(feh_file * file);
-char *chop_file_from_full_path(char *str);
 void feh_event_handle_keypress(XEvent * ev);
 void feh_action_run(feh_file * file, char *action);
 char *feh_printf(char *str, feh_file * file);
@@ -133,6 +132,7 @@ int feh_load_image_char(Imlib_Image * im, char *filename);
 void feh_draw_filename(winwidget w);
 void feh_draw_actions(winwidget w);
 void feh_draw_caption(winwidget w);
+void feh_draw_info(winwidget w);
 void feh_display_status(char stat);
 void real_loadables_mode(int loadable);
 void feh_reload_image(winwidget w, int resize, int force_new);
