@@ -55,7 +55,10 @@ void init_xinerama(void)
 {
 	if (opt.xinerama && XineramaIsActive(disp)) {
 		int major, minor;
-		xinerama_screen = 0;
+		if (getenv("XINERAMA_SCREEN"))
+			xinerama_screen = atoi(getenv("XINERAMA_SCREEN"));
+		else
+			xinerama_screen = 0;
 		XineramaQueryVersion(disp, &major, &minor);
 		xinerama_screens = XineramaQueryScreens(disp, &num_xinerama_screens);
 	}
@@ -116,7 +119,7 @@ int feh_load_image(Imlib_Image * im, feh_file * file)
 {
 	Imlib_Load_Error err;
 
-	D(3, ("filename is %s, image is %p\n", file->filename, im));
+	D(("filename is %s, image is %p\n", file->filename, im));
 
 	if (!file || !file->filename)
 		return(0);
@@ -220,11 +223,11 @@ int feh_load_image(Imlib_Image * im, feh_file * file)
 						file->filename, err);
 			break;
 		}
-		D(3, ("Load *failed*\n"));
+		D(("Load *failed*\n"));
 		return(0);
 	}
 
-	D(3, ("Loaded ok\n"));
+	D(("Loaded ok\n"));
 	return(1);
 }
 
@@ -271,7 +274,7 @@ char *feh_http_load_image(char *url)
 		char accept_string[] = "Accept: image/*";
 		FILE *fp;
 
-		D(4, ("using builtin http collection\n"));
+		D(("using builtin http collection\n"));
 		fp = fopen(tmpname, "w");
 		if (!fp) {
 			weprintf("couldn't write to file %s:", tmpname);
@@ -288,7 +291,7 @@ char *feh_http_load_image(char *url)
 			return(NULL);
 		}
 
-		D(4, ("trying hostname %s\n", hostname));
+		D(("trying hostname %s\n", hostname));
 
 		if (!(hptr = feh_gethostbyname(hostname))) {
 			weprintf("error resolving host %s:", hostname);
@@ -449,7 +452,7 @@ char *feh_http_load_image(char *url)
 				quiet = estrdup("-q");
 
 			execlp("wget", "wget", "--cache=off", "-O", tmpname, url, quiet, NULL);
-			eprintf("url: exec failed: wget:");
+			eprintf("url: Is 'wget' installed? Failed to exec wget:");
 		} else {
 			waitpid(pid, &status, 0);
 
@@ -600,9 +603,8 @@ void feh_draw_filename(winwidget w)
 			IMLIB_TEXT_TO_RIGHT, 0, 0, 0, 255);
 	gib_imlib_text_draw(im, fn, NULL, 1, 1, FEH_FILE(w->file->data)->filename,
 			IMLIB_TEXT_TO_RIGHT, 255, 255, 255, 255);
-	/* Print the position in the filelist, if we are in fullscreen and the
-	 * list has more than one element */
-	if (w->full_screen && (gib_list_length(filelist) - 1)) {
+	/* Print the position in the filelist, if we have >=2 files */
+	if (gib_list_length(filelist) > 1) {
 		/* sic! */
 		len = snprintf(NULL, 0, "%d of %d", gib_list_length(filelist), gib_list_length(filelist)) + 1;
 		s = emalloc(len);
@@ -619,6 +621,80 @@ void feh_draw_filename(winwidget w)
 	return;
 }
 
+void feh_draw_info(winwidget w)
+{
+	static Imlib_Font fn = NULL;
+	int tw = 0, th = 0;
+	Imlib_Image im = NULL;
+	static DATA8 atab[256];
+	int no_lines = 0;
+	char *info_cmd;
+	char info_buf[256];
+	FILE *info_pipe;
+
+	if ((!w->file) || (!FEH_FILE(w->file->data))
+			|| (!FEH_FILE(w->file->data)->filename))
+		return;
+
+	if (opt.font)
+		fn = gib_imlib_load_font(opt.font);
+
+	if (!fn) {
+		if (w->full_screen)
+			fn = gib_imlib_load_font(DEFAULT_FONT_BIG);
+		else
+			fn = gib_imlib_load_font(DEFAULT_FONT);
+	}
+
+	if (!fn) {
+		weprintf("Couldn't load font for filename printing");
+		return;
+	}
+
+	info_cmd = feh_printf(opt.info_cmd, FEH_FILE(w->file->data));
+
+	memset(atab, 0, sizeof(atab));
+
+	gib_imlib_get_text_size(fn, "w", NULL, &tw, &th, IMLIB_TEXT_TO_RIGHT);
+
+	info_pipe = popen(info_cmd, "r");
+
+	im = imlib_create_image(290 * tw, 20 * th);
+	if (!im)
+		eprintf("Couldn't create image. Out of memory?");
+
+	gib_imlib_image_set_has_alpha(im, 1);
+	gib_imlib_apply_color_modifier_to_rectangle(im, 0, 0, 290 * tw, 20 * th, NULL, NULL, NULL, atab);
+	gib_imlib_image_fill_rectangle(im, 0, 0, 290 * tw, 20 * th, 0, 0, 0, 0);
+
+	if (!info_pipe) {
+		gib_imlib_text_draw(im, fn, NULL, 2, 2,
+				"Error runnig info command", IMLIB_TEXT_TO_RIGHT,
+				255, 0, 0, 255);
+		gib_imlib_get_text_size(fn, "Error running info command", NULL, &tw, &th,
+				IMLIB_TEXT_TO_RIGHT);
+		no_lines = 1;
+	}
+	else {
+		while ((no_lines < 20) && fgets(info_buf, 256, info_pipe)) {
+			info_buf[strlen(info_buf)-1] = '\0';
+			gib_imlib_text_draw(im, fn, NULL, 2, (no_lines*th)+2, info_buf,
+					IMLIB_TEXT_TO_RIGHT, 0, 0, 0, 255);
+			gib_imlib_text_draw(im, fn, NULL, 1, (no_lines*th)+1, info_buf,
+					IMLIB_TEXT_TO_RIGHT, 255, 255, 255, 255);
+			no_lines++;
+		}
+		pclose(info_pipe);
+	}
+
+
+	gib_imlib_render_image_on_drawable(w->bg_pmap, im, 2,
+			w->h - (th * no_lines) - 2, 1, 1, 0);
+
+	gib_imlib_free_image_and_decache(im);
+	return;
+}
+
 char *build_caption_filename(feh_file * file)
 {
 	char *caption_filename;
@@ -635,7 +711,7 @@ char *build_caption_filename(feh_file * file)
 
 	caption_dir = estrjoin("/", dir, opt.caption_path, NULL);
 
-	D(4, ("dir %s, cp %s, cdir %s\n", dir, opt.caption_path, caption_dir))
+	D(("dir %s, cp %s, cdir %s\n", dir, opt.caption_path, caption_dir))
 
 	if (stat(caption_dir, &cdir_stat) == -1) {
 		if (mkdir(caption_dir, 0755) == -1)
@@ -789,7 +865,7 @@ void feh_display_status(char stat)
 	static int init_len = 0;
 	int j = 0;
 
-	D(5, ("filelist %p, filelist->next %p\n", filelist, filelist->next));
+	D(("filelist %p, filelist->next %p\n", filelist, filelist->next));
 
 	if (!init_len)
 		init_len = gib_list_length(filelist);
@@ -964,7 +1040,7 @@ void feh_edit_inplace_lossless_rotate(winwidget w, int orientation)
 		execlp("jpegtran", "jpegtran", "-copy", "all", "-rotate",
 				rotate_str, "-outfile", file_str, file_str, NULL);
 
-		eprintf("lossless rotate: exec failed: jpegtran:");
+		eprintf("lossless rotate: Is 'jpegtran' installed? Failed to exec:");
 	} else {
 		waitpid(pid, &status, 0);
 
@@ -1051,10 +1127,8 @@ void feh_draw_actions(winwidget w)
 	/* This depends on feh_draw_filename internals...
 	 * should be fixed some time
 	 */
-	if (opt.draw_filename && w->full_screen)
+	if (opt.draw_filename)
 		th_offset = line_th * 2;
-	else if (opt.draw_filename)
-		th_offset = line_th;
 
 	im = imlib_create_image(tw, th);
 	if (!im)
