@@ -42,6 +42,8 @@ fehoptions opt;
 
 void init_parse_options(int argc, char **argv)
 {
+	/* TODO: sort these to match declaration of __fehoptions */
+
 	/* For setting the command hint on X windows */
 	cmdargc = argc;
 	cmdargv = argv;
@@ -59,7 +61,6 @@ void init_parse_options(int argc, char **argv)
 	opt.image_bg = estrdup("default");
 	opt.menu_bg = estrdup(PREFIX "/share/feh/images/menubg_default.png");
 	opt.menu_style = estrdup(PREFIX "/share/feh/fonts/menu.style");
-	opt.menu_border = 4;
 
 	opt.reload_button = 0;
 	opt.pan_button = 1;
@@ -69,13 +70,15 @@ void init_parse_options(int argc, char **argv)
 	opt.prev_button = 4;
 	opt.next_button = 5;
 
+	opt.draw_actions = 0;
+
 	opt.rotate_button = 2;
 	opt.no_rotate_ctrl_mask = 0;
 	opt.blur_button = 1;
 	opt.no_blur_ctrl_mask = 0;
 
 	opt.start_list_at = NULL;
-	opt.no_jump_on_resort = 0;
+	opt.jump_on_resort = 1;
 
 	opt.builtin_http = 0;
 
@@ -86,15 +89,15 @@ void init_parse_options(int argc, char **argv)
 	opt.xinerama = 1;
 #endif				/* HAVE_LIBXINERAMA */
 
-	D(3, ("About to parse env options (if any)\n"));
+	D(("About to parse env options (if any)\n"));
 	/* Check for and parse any options in FEH_OPTIONS */
 	feh_parse_environment_options();
 
-	D(3, ("About to parse commandline options\n"));
+	D(("About to parse commandline options\n"));
 	/* Parse the cmdline args */
 	feh_parse_option_array(argc, argv);
 
-	D(3, ("About to check for theme configuration\n"));
+	D(("About to check for theme configuration\n"));
 	feh_check_theme_options(argc, argv);
 
 	/* If we have a filelist to read, do it now */
@@ -102,11 +105,11 @@ void init_parse_options(int argc, char **argv)
 		/* joining two reverse-sorted lists in this manner works nicely for us
 		   here, as files specified on the commandline end up at the *end* of
 		   the combined filelist, in the specified order. */
-		D(3, ("About to load filelist from file\n"));
+		D(("About to load filelist from file\n"));
 		filelist = gib_list_cat(filelist, feh_read_filelist(opt.filelistfile));
 	}
 
-	D(4, ("Options parsed\n"));
+	D(("Options parsed\n"));
 
 	if (opt.bgmode)
 		return;
@@ -132,7 +135,7 @@ static void feh_check_theme_options(int arg, char **argv)
 		else
 			theme = estrdup(argv[0]);
 	}
-	D(3, ("Theme name is %s\n", theme));
+	D(("Theme name is %s\n", theme));
 
 	feh_load_options_for_theme(theme);
 
@@ -161,7 +164,7 @@ static void feh_load_options_for_theme(char *theme)
 			eprintf("D'oh! Please define HOME in your environment! "
 					"It would really help me out...\n");
 		rcpath = estrjoin("/", home, ".fehrc", NULL);
-		D(3, ("Trying %s for config\n", rcpath));
+		D(("Trying %s for config\n", rcpath));
 		fp = fopen(rcpath, "r");
 
 		if (!fp && ((fp = fopen("/etc/fehrc", "r")) == NULL)) {
@@ -183,14 +186,14 @@ static void feh_load_options_for_theme(char *theme)
 			sscanf(s, " %[^\n]\n", (char *) &s2);
 			if (!*s2)
 				break;
-			D(5, ("Got continued options %s\n", s2));
+			D(("Got continued options %s\n", s2));
 		} else {
 			sscanf(s, "%s %[^\n]\n", (char *) &s1, (char *) &s2);
 			if (!(*s1) || (!*s2) || (*s1 == '\n') || (*s1 == '#')) {
 				cont = 0;
 				continue;
 			}
-			D(5, ("Got theme/options pair %s/%s\n", s1, s2));
+			D(("Got theme/options pair %s/%s\n", s1, s2));
 		}
 
 		if (!strcmp(s1, theme) || cont) {
@@ -198,7 +201,7 @@ static void feh_load_options_for_theme(char *theme)
 			bspos = strlen(s2)-1;
 
 			if (s2[bspos] == '\\') {
-				D(5, ("Continued line\n"));
+				D(("Continued line\n"));
 				s2[bspos] = '\0';
 				cont = 1;
 				/* A trailing whitespace confuses the option parser */
@@ -207,7 +210,7 @@ static void feh_load_options_for_theme(char *theme)
 			} else
 				cont = 0;
 
-			D(4, ("A match. Using options %s\n", s2));
+			D(("A match. Using options %s\n", s2));
 			feh_parse_options_from_string(s2);
 
 			if (!cont)
@@ -289,7 +292,7 @@ char *feh_string_normalize(char *str)
 	int i = 0;
 	char last = 0;
 
-	D(4, ("normalizing %s\n", str));
+	D(("normalizing %s\n", str));
 	ret[0] = '\0';
 
 	for (s = str;; s++) {
@@ -309,7 +312,7 @@ char *feh_string_normalize(char *str)
 		ret[i - 1] = '\0';
 	else
 		ret[i] = '\0';
-	D(4, ("normalized to %s\n", ret));
+	D(("normalized to %s\n", ret));
 
 	return(estrdup(ret));
 }
@@ -317,113 +320,117 @@ char *feh_string_normalize(char *str)
 static void feh_parse_option_array(int argc, char **argv)
 {
 	static char stropts[] =
-	    "a:A:b:B:cC:dD:e:E:f:Fg:hH:iIj:klL:mM:nNo:O:pqQrR:sS:tT:uUvVwW:xXy:zZ0:1:2:4:5:8:9:.@:^:~:):|:_:+:";
+		"a:A:b:B:cC:dD:e:E:f:Fg:GhH:iIj:J:kK:lL:mM:nNo:O:pPqQrR:sS:tT:uUvVwW:xXy:YzZ"
+		"0:1:2:4:5:8:9:.@:^:~:):|:_:+:";
+
+	/* (*name, has_arg, *flag, val) See: struct option in getopts.h */
 	static struct option lopts[] = {
-		/* actions */
-		{"help", 0, 0, 'h'},	/* okay */
-		{"version", 0, 0, 'v'},	/* okay */
-		/* toggles */
-		{"montage", 0, 0, 'm'},	/* okay */
-		{"collage", 0, 0, 'c'},	/* okay */
-		{"index", 0, 0, 'i'},	/* okay */
-		{"fullindex", 0, 0, 'I'},	/* okay */
-		{"verbose", 0, 0, 'V'},	/* okay */
-		{"borderless", 0, 0, 'x'},	/* okay */
-		{"keep-http", 0, 0, 'k'},	/* okay */
-		{"stretch", 0, 0, 's'},	/* okay */
-		{"multiwindow", 0, 0, 'w'},	/* okay */
-		{"recursive", 0, 0, 'r'},	/* okay */
-		{"randomize", 0, 0, 'z'},	/* okay */
-		{"list", 0, 0, 'l'},	/* okay */
-		{"quiet", 0, 0, 'q'},	/* okay */
-		{"loadable", 0, 0, 'U'},	/* okay */
-		{"unloadable", 0, 0, 'u'},	/* okay */
-		{"no-menus", 0, 0, 'N'},
-		{"full-screen", 0, 0, 'F'},
-		{"auto-zoom", 0, 0, 'Z'},
-		{"ignore-aspect", 0, 0, 'X'},
-		{"draw-filename", 0, 0, 'd'},
-		{"preload", 0, 0, 'p'},
-		{"reverse", 0, 0, 'n'},
-		{"thumbnails", 0, 0, 't'},
-		{"builtin", 0, 0, 'Q'},
-		{"scale-down", 0, 0, '.'},	/* okay */
+		{"help"          , 0, 0, 'h'},
+		{"version"       , 0, 0, 'v'},
+		{"montage"       , 0, 0, 'm'},
+		{"collage"       , 0, 0, 'c'},
+		{"index"         , 0, 0, 'i'},
+		{"fullindex"     , 0, 0, 'I'},
+		{"verbose"       , 0, 0, 'V'},
+		{"borderless"    , 0, 0, 'x'},
+		{"keep-http"     , 0, 0, 'k'},
+		{"stretch"       , 0, 0, 's'},
+		{"multiwindow"   , 0, 0, 'w'},
+		{"recursive"     , 0, 0, 'r'},
+		{"randomize"     , 0, 0, 'z'},
+		{"list"          , 0, 0, 'l'},
+		{"quiet"         , 0, 0, 'q'},
+		{"loadable"      , 0, 0, 'U'},
+		{"unloadable"    , 0, 0, 'u'},
+		{"no-menus"      , 0, 0, 'N'},
+		{"full-screen"   , 0, 0, 'F'}, /* deprecated */
+		{"fullscreen"    , 0, 0, 'F'},
+		{"auto-zoom"     , 0, 0, 'Z'},
+		{"ignore-aspect" , 0, 0, 'X'},
+		{"draw-filename" , 0, 0, 'd'},
+		{"preload"       , 0, 0, 'p'},
+		{"reverse"       , 0, 0, 'n'},
+		{"thumbnails"    , 0, 0, 't'},
+		{"builtin"       , 0, 0, 'Q'},
+		{"scale-down"    , 0, 0, '.'},
 		{"no-jump-on-resort", 0, 0, 220},
-		{"hide-pointer", 0, 0, 221},
-		{"draw-actions", 0, 0, 222},
-		{"cache-thumbnails", 0, 0, 223},
-		{"cycle-once", 0, 0, 224},
-		{"no-xinerama", 0, 0, 225},
+		{"hide-pointer"  , 0, 0, 'Y'},
+		{"draw-actions"  , 0, 0, 'G'},
+		{"cache-thumbnails", 0, 0, 'P'},
+		{"cycle-once"    , 0, 0, 224},
+		{"no-xinerama"   , 0, 0, 225},
 		{"no-rotate-ctrl-mask", 0, 0, 226},
 		{"no-blur-ctrl-mask", 0, 0, 227},
-		{"menu-ctrl-mask", 0, 0, 228},	/* okay */
-		/* options with values */
-		{"output", 1, 0, 'o'},	/* okay */
-		{"output-only", 1, 0, 'O'},	/* okay */
-		{"action", 1, 0, 'A'},	/* okay */
-		{"limit-width", 1, 0, 'W'},	/* okay */
-		{"limit-height", 1, 0, 'H'},	/* okay */
-		{"reload", 1, 0, 'R'},	/* okay */
-		{"alpha", 1, 0, 'a'},	/* okay */
-		{"sort", 1, 0, 'S'},	/* okay */
-		{"theme", 1, 0, 'T'},	/* okay */
-		{"filelist", 1, 0, 'f'},	/* okay */
-		{"customlist", 1, 0, 'L'},	/* okay */
-		{"geometry", 1, 0, 'g'},	/* okay */
-		{"menu-font", 1, 0, 'M'},
-		{"thumb-width", 1, 0, 'y'},
-		{"thumb-height", 1, 0, 'E'},
-		{"slideshow-delay", 1, 0, 'D'},
-		{"font", 1, 0, 'e'},
-		{"title-font", 1, 0, '@'},
-		{"title", 1, 0, '^'},
-		{"thumb-title", 1, 0, '~'},
-		{"bg", 1, 0, 'b'},
-		{"fontpath", 1, 0, 'C'},
-		{"menu-bg", 1, 0, ')'},
-		{"image-bg", 1, 0, 'B'},
-		{"reload-button", 1, 0, '0'},
-		{"pan-button", 1, 0, '1'},
-		{"zoom-button", 1, 0, '2'},
-		{"menu-button", 1, 0, '3'},
-		{"prev-button", 1, 0, '4'},
-		{"next-button", 1, 0, '5'},
-		{"rotate-button", 1, 0, '8'},
-		{"blur-button", 1, 0, '9'},
-		{"start-at", 1, 0, '|'},
-		{"rcfile", 1, 0, '_'},
-		{"debug-level", 1, 0, '+'},
-		{"output-dir", 1, 0, 'j'},
-		{"bg-tile", 1, 0, 200},
-		{"bg-center", 1, 0, 201},
-		{"bg-scale", 1, 0, 202},
-		{"bg-seamless", 1, 0, 203},
-		{"menu-style", 1, 0, 204},
-		{"zoom", 1, 0, 205},
+		{"menu-ctrl-mask", 0, 0, 228},
+
+		{"output"        , 1, 0, 'o'},
+		{"output-only"   , 1, 0, 'O'},
+		{"action"        , 1, 0, 'A'},
+		{"limit-width"   , 1, 0, 'W'},
+		{"limit-height"  , 1, 0, 'H'},
+		{"reload"        , 1, 0, 'R'},
+		{"alpha"         , 1, 0, 'a'},
+		{"sort"          , 1, 0, 'S'},
+		{"theme"         , 1, 0, 'T'},
+		{"filelist"      , 1, 0, 'f'},
+		{"customlist"    , 1, 0, 'L'},
+		{"geometry"      , 1, 0, 'g'},
+		{"menu-font"     , 1, 0, 'M'},
+		{"thumb-width"   , 1, 0, 'y'},
+		{"thumb-height"  , 1, 0, 'E'},
+		{"slideshow-delay",1, 0, 'D'},
+		{"font"          , 1, 0, 'e'},
+		{"title-font"    , 1, 0, '@'},
+		{"title"         , 1, 0, '^'},
+		{"thumb-title"   , 1, 0, '~'},
+		{"bg"            , 1, 0, 'b'},
+		{"fontpath"      , 1, 0, 'C'},
+		{"menu-bg"       , 1, 0, ')'},
+		{"image-bg"      , 1, 0, 'B'},
+		{"reload-button" , 1, 0, '0'},
+		{"pan-button"    , 1, 0, '1'},
+		{"zoom-button"   , 1, 0, '2'},
+		{"menu-button"   , 1, 0, '3'},
+		{"prev-button"   , 1, 0, '4'},
+		{"next-button"   , 1, 0, '5'},
+		{"rotate-button" , 1, 0, '8'},
+		{"blur-button"   , 1, 0, '9'},
+		{"start-at"      , 1, 0, '|'},
+		{"rcfile"        , 1, 0, '_'},
+		{"debug"         , 0, 0, '+'},
+		{"output-dir"    , 1, 0, 'j'},
+		{"bg-tile"       , 1, 0, 200},
+		{"bg-center"     , 1, 0, 201},
+		{"bg-scale"      , 1, 0, 202},
+		{"menu-style"    , 1, 0, 204},
+		{"zoom"          , 1, 0, 205},
 		{"no-screen-clip", 0, 0, 206},
-		{"menu-border", 1, 0, 207},
-		{"caption-path", 1, 0, 208},
-		{"action1", 1, 0, 209},
-		{"action2", 1, 0, 210},
-		{"action3", 1, 0, 211},
-		{"action4", 1, 0, 212},
-		{"action5", 1, 0, 213},
-		{"action6", 1, 0, 214},
-		{"action7", 1, 0, 215},
-		{"action8", 1, 0, 216},
-		{"action9", 1, 0, 217},
-		{"bg-fill", 1, 0, 218},
-		{"index-name", 1, 0, 230},
-		{"index-size", 1, 0, 231},
-		{"index-dim", 1, 0, 232},
-		{"thumb-redraw", 1, 0, 233},
+		{"caption-path"  , 1, 0, 'K'},
+		{"action1"       , 1, 0, 209},
+		{"action2"       , 1, 0, 210},
+		{"action3"       , 1, 0, 211},
+		{"action4"       , 1, 0, 212},
+		{"action5"       , 1, 0, 213},
+		{"action6"       , 1, 0, 214},
+		{"action7"       , 1, 0, 215},
+		{"action8"       , 1, 0, 216},
+		{"action9"       , 1, 0, 217},
+		{"bg-fill"       , 1, 0, 218},
+		{"bg-max"        , 1, 0, 219},
+		{"index-name"    , 1, 0, 230},
+		{"index-size"    , 1, 0, 231},
+		{"index-dim"     , 1, 0, 232},
+		{"thumb-redraw"  , 1, 0, 'J'},
+		{"info"          , 1, 0, 234},
+
 		{0, 0, 0, 0}
 	};
 	int optch = 0, cmdx = 0;
+	int i = 0;
 
 	/* Now to pass some optionarinos */
 	while ((optch = getopt_long(argc, argv, stropts, lopts, &cmdx)) != EOF) {
-		D(5, ("Got option, getopt calls it %d, or %c\n", optch, optch));
+		D(("Got option, getopt calls it %d, or %c\n", optch, optch));
 		switch (optch) {
 		case 0:
 			break;
@@ -473,7 +480,7 @@ static void feh_parse_option_array(int argc, char **argv)
 			opt.menu_font = estrdup(optarg);
 			break;
 		case '+':
-			opt.debug_level = atoi(optarg);
+			opt.debug = 1;
 			break;
 		case 'n':
 			opt.reverse = 1;
@@ -565,7 +572,7 @@ static void feh_parse_option_array(int argc, char **argv)
 			theme = estrdup(optarg);
 			break;
 		case 'C':
-			D(3, ("adding fontpath %s\n", optarg));
+			D(("adding fontpath %s\n", optarg));
 			imlib_add_path_to_font_path(optarg);
 			break;
 		case 'e':
@@ -675,14 +682,14 @@ static void feh_parse_option_array(int argc, char **argv)
 			opt.bgmode = BG_MODE_SCALE;
 			opt.output_file = estrdup(optarg);
 			break;
-		case 203:
-			opt.bgmode = BG_MODE_SEAMLESS;
-			opt.output_file = estrdup(optarg);
-			break;
 		case 218:
 			opt.bgmode = BG_MODE_FILL;
 			opt.output_file = estrdup(optarg);
 			break;
+		case 219:
+			opt.bgmode = BG_MODE_MAX;
+			opt.output_file = estrdup(optarg);
+			break;
 		case 204:
 			free(opt.menu_style);
 			opt.menu_style = estrdup(optarg);
@@ -693,10 +700,7 @@ static void feh_parse_option_array(int argc, char **argv)
 		case 206:
 			opt.screen_clip = 0;
 			break;
-		case 207:
-			opt.menu_border = atoi(optarg);
-			break;
-		case 208:
+		case 'K':
 			opt.caption_path = estrdup(optarg);
 			break;
 		case 209:
@@ -727,15 +731,15 @@ static void feh_parse_option_array(int argc, char **argv)
 			opt.actions[9] = estrdup(optarg);
 			break;
 		case 220:
-			opt.no_jump_on_resort = 1;
+			opt.jump_on_resort = 0;
 			break;
-		case 221:
+		case 'Y':
 			opt.hide_pointer = 1;
 			break;
-		case 222:
+		case 'G':
 			opt.draw_actions = 1;
 			break;
-		case 223:
+		case 'P':
 			opt.cache_thumbnails = 1;
 			break;
 		case 224:
@@ -762,9 +766,12 @@ static void feh_parse_option_array(int argc, char **argv)
 		case 232:
 			opt.index_show_dim = atoi(optarg);
 			break;
-		case 233:
+		case 'J':
 			opt.thumb_redraw = atoi(optarg);
 			break;
+		case 234:
+			opt.info_cmd = estrdup(optarg);
+			break;
 		default:
 			break;
 		}
@@ -779,6 +786,13 @@ static void feh_parse_option_array(int argc, char **argv)
 		}
 	}
 
+	for (i = 0; i < 10; i++) {
+		if (opt.actions[i] && !opt.hold_actions[i] && (opt.actions[i][0] == ';')) {
+			opt.hold_actions[i] = 1;
+			opt.actions[i] = &opt.actions[i][1];
+		}
+	}
+
 	/* So that we can safely be called again */
 	optind = 1;
 	return;
