@@ -48,7 +48,7 @@ struct __fehoptions {
 	unsigned char keep_http;
 	unsigned char borderless;
 	unsigned char randomize;
-	unsigned char no_jump_on_resort;
+	unsigned char jump_on_resort;
 	unsigned char full_screen;
 	unsigned char auto_zoom;
 	unsigned char draw_filename;
@@ -68,6 +68,7 @@ struct __fehoptions {
 	unsigned char draw_actions;
 	unsigned char cache_thumbnails;
 	unsigned char cycle_once;
+	unsigned char hold_actions[10];
 
 	char *output_file;
 	char *output_dir;
@@ -87,6 +88,7 @@ struct __fehoptions {
 	char *menu_style;
 	char *caption_path;
 	char *start_list_at;
+	char *info_cmd;
 
 	gib_style *menu_style_l;
 
@@ -111,14 +113,13 @@ struct __fehoptions {
 	unsigned int thumb_redraw;
 	int reload;
 	int sort;
-	int debug_level;
+	int debug;
 	int geom_flags;
 	int geom_x;
 	int geom_y;
 	unsigned int geom_w;
 	unsigned int geom_h;
 	int default_zoom;
-	int menu_border;
 	unsigned char adjust_reload;
 
 	unsigned char mode;
