@@ -51,10 +51,6 @@ void feh_wm_set_bg_file(char *file, unsigned char bgmode)
 		if (feh_load_image(&im, fil) == 0)
 			eprintf("Couldn't load image in order to set bg");
 		switch (bgmode) {
-		case BG_MODE_SEAMLESS:
-			gib_imlib_image_tile(im);
-			feh_wm_set_bg(NULL, im, 0, 0, 0, 0, 1);
-			break;
 		case BG_MODE_TILE:
 			feh_wm_set_bg(file, im, 0, 0, 0, 0, 1);
 			break;
@@ -64,6 +60,9 @@ void feh_wm_set_bg_file(char *file, unsigned char bgmode)
 		case BG_MODE_FILL:
 			feh_wm_set_bg(file, im, 0, 0, 1, 0, 1);
 			break;
+		case BG_MODE_MAX:
+			feh_wm_set_bg(file, im, 0, 0, 2, 0, 1);
+			break;
 		default:
 			feh_wm_set_bg(file, im, 1, 0, 0, 0, 1);
 			break;
@@ -88,10 +87,10 @@ void feh_wm_set_bg(char *fil, Imlib_Image im, int centered, int scaled,
 		imlib_context_set_image(im);
 		imlib_image_set_format("png");
 		gib_imlib_save_image(im, bgfil);
-		D(3, ("bg saved as %s\n", bgfil));
+		D(("bg saved as %s\n", bgfil));
 		fil = bgfil;
 	}
-	D(3, ("Setting bg %s\n", fil));
+	D(("Setting bg %s\n", fil));
 
 	if (feh_wm_get_wm_is_e() && (enl_ipc_get_win() != None)) {
 		snprintf(sendbuf, sizeof(sendbuf), "background %s bg.file %s", bgname, fil);
@@ -148,7 +147,7 @@ void feh_wm_set_bg(char *fil, Imlib_Image im, int centered, int scaled,
 		GC gc;
 		int in, out, w, h;
 
-		D(3, ("Falling back to XSetRootWindowPixmap\n"));
+		D(("Falling back to XSetRootWindowPixmap\n"));
 
 		/* Put the filename in filbuf between ' and escape ' in the filename */
 		out = 0;
@@ -183,7 +182,7 @@ void feh_wm_set_bg(char *fil, Imlib_Image im, int centered, int scaled,
 			GC gc;
 			int x, y;
 
-			D(3, ("centering\n"));
+			D(("centering\n"));
 			w = scr->width;
 			h = scr->height;
 
@@ -205,27 +204,66 @@ void feh_wm_set_bg(char *fil, Imlib_Image im, int centered, int scaled,
 			gib_imlib_render_image_on_drawable(pmap_d1, im, x, y, 1, 0, 0);
 			XFreeGC(disp, gc);
 			fehbg = estrjoin(" ", "feh --bg-center", filbuf, NULL);
-		} else if (filled) {
-			int x = scr->width;
-			int y = scr->height;
-			int u = gib_imlib_image_get_width(im);
-			int v = gib_imlib_image_get_height(im);
-			int s = 0;
-			int t = 0;
+		} else if (filled == 1) {
+			int scr_w = scr->width;
+			int scr_h = scr->height;
+			int img_w = gib_imlib_image_get_width(im);
+			int img_h = gib_imlib_image_get_height(im);
+			int render_x = 0;
+			int render_y = 0;
 
-			if ((u * y) > (x * v)) {
-				h = y;
-				w = (y * u) / v;
-				s = (x - w) / 2;
+			if ((img_w * scr_h) > (scr_w * img_h)) {
+				h = scr_h;
+				w = (scr_h * img_w) / img_h;
+				render_x = (scr_w - w) / 2;
 			} else {
-				h = (x * v) / u;
-				w = x;
-				t = (y - h) / 2;
+				h = (scr_w * img_h) / img_w;
+				w = scr_w;
+				render_y = (scr_h - h) / 2;
 			}
 			pmap_d1 = XCreatePixmap(disp, root, w, h, depth);
-			gib_imlib_render_image_on_drawable_at_size(pmap_d1, im, s, t,
-					w, h, 1, 0, 1);
+			gib_imlib_render_image_on_drawable_at_size(pmap_d1, im,
+					render_x, render_y, w, h, 1, 0, 1);
 			fehbg = estrjoin(" ", "feh --bg-fill", filbuf, NULL);
+		} else if (filled == 2) {
+			int scr_w = scr->width;
+			int scr_h = scr->height;
+			int img_w = gib_imlib_image_get_width(im);
+			int img_h = gib_imlib_image_get_height(im);
+			int render_x = 0;
+			int render_y = 0;
+			XGCValues gcval;
+
+			if (img_w > img_h) {
+				w = scr_w;
+				h = (((scr_w * 100) / img_w) * img_h) / 100;
+				render_y = (scr_h - h) / 2;
+				if (h > scr_h) {
+					w = (((scr_h * 100) / h) * w) / 100;
+					h = scr_h;
+					render_x = (scr_w - w) / 2;
+					render_y = 0;
+				}
+			} else {
+				h = scr_h;
+				w = (((scr_h * 100) / img_h) * img_w) / 100;
+				render_x = (scr_w - w) / 2;
+				if (w > scr_w) {
+					h = (((scr_w * 100) / w) * h) / 100;
+					w = scr_w;
+					render_x = 0;
+					render_y = (scr_h - h) / 2;
+				}
+			}
+
+			pmap_d1 = XCreatePixmap(disp, root, scr_w, scr_h, depth);
+			gcval.foreground = BlackPixel(disp, DefaultScreen(disp));
+			gc = XCreateGC(disp, root, GCForeground, &gcval);
+			XFillRectangle(disp, pmap_d1, gc, 0, 0, scr_w, scr_h);
+			gib_imlib_render_image_on_drawable_at_size(pmap_d1, im,
+					render_x, render_y, w, h, 1, 0, 1);
+			XFreeGC(disp, gc);
+			fehbg = estrjoin(" ", "feh --bg-max", filbuf, NULL);
 		} else {
 			w = gib_imlib_image_get_width(im);
 			h = gib_imlib_image_get_height(im);
@@ -316,10 +354,10 @@ signed char feh_wm_get_wm_is_e(void)
 		/* XXX: This only covers E17 prior to 6/22/05 */
 		if ((XInternAtom(disp, "ENLIGHTENMENT_COMMS", True) != None)
 		    && (XInternAtom(disp, "ENLIGHTENMENT_VERSION", True) != None)) {
-			D(3, ("Enlightenment detected.\n"));
+			D(("Enlightenment detected.\n"));
 			e = 1;
 		} else {
-			D(3, ("Enlightenment not detected.\n"));
+			D(("Enlightenment not detected.\n"));
 			e = 0;
 		}
 	}
@@ -337,7 +375,7 @@ int feh_wm_get_num_desks(void)
 	buf = enl_send_and_wait("num_desks ?");
 	if (buf == IPC_FAKE)	/* Fake E17 IPC */
 		return(-1);
-	D(3, ("Got from E IPC: %s\n", buf));
+	D(("Got from E IPC: %s\n", buf));
 	ptr = buf;
 	while (ptr && !isdigit(*ptr))
 		ptr++;
@@ -357,7 +395,7 @@ Window enl_ipc_get_win(void)
 	int dummy_int;
 	unsigned int dummy_uint;
 
-	D(3, ("Searching for IPC window.\n"));
+	D(("Searching for IPC window.\n"));
 
 	/*
 	 * Shortcircuit this entire func
@@ -368,14 +406,14 @@ Window enl_ipc_get_win(void)
 
 		    prop = XInternAtom(disp, "ENLIGHTENMENT_COMMS", True);
 	if (prop == None) {
-		D(3, ("Enlightenment is not running.\n"));
+		D(("Enlightenment is not running.\n"));
 		return(None);
 	} else {
 		/* XXX: This will only work with E17 prior to 6/22/2005 */
 		ever = XInternAtom(disp, "ENLIGHTENMENT_VERSION", True);
 		if (ever == None) {
 			/* This is an E without ENLIGHTENMENT_VERSION */
-			D(3, ("E16 IPC Protocol not supported"));
+			D(("E16 IPC Protocol not supported"));
 			return(None);
 		}
 	}
@@ -388,7 +426,7 @@ Window enl_ipc_get_win(void)
 		if (!XGetGeometry
 		    (disp, ipc_win, &dummy_win, &dummy_int, &dummy_int,
 		     &dummy_uint, &dummy_uint, &dummy_uint, &dummy_uint)) {
-			D(3, (" -> IPC Window property is valid, but the window doesn't exist.\n"));
+			D((" -> IPC Window property is valid, but the window doesn't exist.\n"));
 			ipc_win = None;
 		}
 		str = NULL;
@@ -398,7 +436,7 @@ Window enl_ipc_get_win(void)
 			if (str) {
 				XFree(str);
 			} else {
-				D(3, (" -> IPC Window lacks the proper atom.  I can't talk to fake IPC windows....\n"));
+				D((" -> IPC Window lacks the proper atom.  I can't talk to fake IPC windows....\n"));
 				ipc_win = None;
 			}
 		}
@@ -416,14 +454,13 @@ Window enl_ipc_get_win(void)
 			 * -- richlowe 2005-06-22
 			 */
 			XFree(str);
-			D(3, (" -> Found a fake E17 IPC window, ignoring"));
+			D((" -> Found a fake E17 IPC window, ignoring"));
 			ipc_win = None;
 			e17_fake_ipc = 1;
 			return(ipc_win);
 		}
 
-		D(3,
-		  (" -> IPC Window found and verified as 0x%08x.  Registering feh as an IPC client.\n", (int) ipc_win));
+		D((" -> IPC Window found and verified as 0x%08x.  Registering feh as an IPC client.\n", (int) ipc_win));
 		XSelectInput(disp, ipc_win, StructureNotifyMask | SubstructureNotifyMask);
 		enl_ipc_send("set clientname " PACKAGE);
 		enl_ipc_send("set version " VERSION);
@@ -451,24 +488,24 @@ void enl_ipc_send(char *str)
 		if (last_msg == NULL)
 			eprintf("eeek");
 		str = last_msg;
-		D(4, ("Resending last message \"%s\" to Enlightenment.\n", str));
+		D(("Resending last message \"%s\" to Enlightenment.\n", str));
 	} else {
 		if (last_msg != NULL) {
 			free(last_msg);
 		}
 		last_msg = estrdup(str);
-		D(4, ("Sending \"%s\" to Enlightenment.\n", str));
+		D(("Sending \"%s\" to Enlightenment.\n", str));
 	}
 	if (ipc_win == None) {
 		if ((ipc_win = enl_ipc_get_win()) == None) {
-			D(3, ("Hrm. Enlightenment doesn't seem to be running. No IPC window, no IPC.\n"));
+			D(("Hrm. Enlightenment doesn't seem to be running. No IPC window, no IPC.\n"));
 			return;
 		}
 	}
 	len = strlen(str);
 	ipc_atom = XInternAtom(disp, "ENL_MSG", False);
 	if (ipc_atom == None) {
-		D(3, ("IPC error:  Unable to find/create ENL_MSG atom.\n"));
+		D(("IPC error:  Unable to find/create ENL_MSG atom.\n"));
 		return;
 	}
 	for (; XCheckTypedWindowEvent(disp, my_ipc_win, ClientMessage, &ev););	/* Discard any out-of-sync messages */
@@ -552,7 +589,7 @@ char *enl_ipc_get(const char *msg_data)
 	if (blen < 12) {
 		ret_msg = message;
 		message = NULL;
-		D(4, ("Received complete reply:  \"%s\"\n", ret_msg));
+		D(("Received complete reply:  \"%s\"\n", ret_msg));
 	}
 	return(ret_msg);
 }
@@ -586,7 +623,7 @@ char *enl_send_and_wait(char *msg)
 		for (; !(reply = enl_ipc_get(enl_wait_for_reply())););
 		if (reply == IPC_TIMEOUT) {
 			/* We timed out.  The IPC window must be AWOL.  Reset and resend message. */
-			D(3, ("IPC timed out.  IPC window has gone. Clearing ipc_win.\n"));
+			D(("IPC timed out.  IPC window has gone. Clearing ipc_win.\n"));
 			XSelectInput(disp, ipc_win, None);
 			ipc_win = None;
 		}
