@@ -127,7 +127,7 @@ winwidget winwidget_create_from_file(gib_list * list, char *name, char type)
 	if (!ret->win) {
 		ret->w = ret->im_w = gib_imlib_image_get_width(ret->im);
 		ret->h = ret->im_h = gib_imlib_image_get_height(ret->im);
-		D(3, ("image is %dx%d pixels, format %s\n", ret->w, ret->h, gib_imlib_image_format(ret->im)));
+		D(("image is %dx%d pixels, format %s\n", ret->w, ret->h, gib_imlib_image_format(ret->im)));
 		if (opt.full_screen)
 			ret->full_screen = True;
 		winwidget_create_window(ret, ret->w, ret->h);
@@ -146,6 +146,9 @@ void winwidget_create_window(winwidget ret, int w, int h)
 	Atom prop = None;
 	int x = 0;
 	int y = 0;
+	char *tmpname;
+
+	D(("winwidget_create_window %dx%d\n", w, h));
 
 	if (ret->full_screen) {
 		w = scr->width;
@@ -155,6 +158,8 @@ void winwidget_create_window(winwidget ret, int w, int h)
 		if (opt.xinerama && xinerama_screens) {
 			w = xinerama_screens[xinerama_screen].width;
 			h = xinerama_screens[xinerama_screen].height;
+			x = xinerama_screens[xinerama_screen].x_org;
+			y = xinerama_screens[xinerama_screen].y_org;
 		}
 #endif				/* HAVE_LIBXINERAMA */
 	} else if (opt.geom_flags) {
@@ -194,6 +199,13 @@ void winwidget_create_window(winwidget ret, int w, int h)
 #endif				/* HAVE_LIBXINERAMA */
 	}
 
+	if (opt.paused) {
+		printf("name %s\n", ret->name);
+		tmpname = estrjoin(" ", ret->name, "[Paused]", NULL);
+		free(ret->name);
+		ret->name = tmpname;
+	}
+
 	ret->x = x;
 	ret->y = y;
 	ret->w = w;
@@ -288,7 +300,7 @@ void winwidget_update_title(winwidget ret)
 {
 	char *name;
 
-	D(4, ("winwid->name = %s\n", ret->name));
+	D(("winwid->name = %s\n", ret->name));
 	name = ret->name ? ret->name : "feh";
 	XStoreName(disp, ret->win, name);
 	XSetIconName(disp, ret->win, name);
@@ -296,6 +308,29 @@ void winwidget_update_title(winwidget ret)
 	return;
 }
 
+void winwidget_update_caption(winwidget winwid)
+{
+	if (opt.caption_path) {
+		/* TODO: Does someone understand the caching here. Is this the right
+		 * approach now that I have broken this out into a separate function. -lsmith */
+
+		/* cache bg pixmap. during caption entry, multiple redraws are done
+		 * because the caption overlay changes - the image doesn't though, so re-
+		 * rendering that is a waste of time */
+		if (winwid->caption_entry) {
+			GC gc;
+			if (winwid->bg_pmap_cache)
+				XFreePixmap(disp, winwid->bg_pmap_cache);
+			winwid->bg_pmap_cache = XCreatePixmap(disp, winwid->win, winwid->w, winwid->h, depth);
+			gc = XCreateGC(disp, winwid->win, 0, NULL);
+			XCopyArea(disp, winwid->bg_pmap, winwid->bg_pmap_cache, gc, 0, 0, winwid->w, winwid->h, 0, 0);
+			XFreeGC(disp, gc);
+		}
+		feh_draw_caption(winwid);
+	}
+	return;
+}
+
 void winwidget_setup_pixmaps(winwidget winwid)
 {
 	if (winwid->full_screen) {
@@ -311,7 +346,7 @@ void winwidget_setup_pixmaps(winwidget winwid)
 		XFillRectangle(disp, winwid->bg_pmap, winwid->gc, 0, 0, scr->width, scr->height);
 	} else {
 		if (!winwid->bg_pmap || winwid->had_resize) {
-			D(4, ("recreating background pixmap (%dx%d)\n", winwid->w, winwid->h));
+			D(("recreating background pixmap (%dx%d)\n", winwid->w, winwid->h));
 			if (winwid->bg_pmap)
 				XFreePixmap(disp, winwid->bg_pmap);
 
@@ -342,22 +377,25 @@ void winwidget_render_image(winwidget winwid, int resize, int alias)
 	if (winwid->im_y > winwid->h)
 		winwid->im_y = winwid->h;
 
+	D(("winwidget_render_image resize %d alias %d im %dx%d\n",
+	      resize, alias, winwid->im_w, winwid->im_h));
+
 	winwidget_setup_pixmaps(winwid);
 
+	if (!winwid->full_screen && opt.scale_down && ((winwid->w < winwid->im_w)
+						       || (winwid->h < winwid->im_h))) {
+		D(("scaling down image %dx%d\n", winwid->w, winwid->h));
+
+		feh_calc_needed_zoom(&(winwid->zoom), winwid->im_w, winwid->im_h, winwid->w, winwid->h);
+		D(("after scaling down image %dx%d\n", winwid->w, winwid->h));
+	}
+
 	if (!winwid->full_screen && ((gib_imlib_image_has_alpha(winwid->im)) || (opt.geom_flags)
 				     || (winwid->im_x || winwid->im_y) || (winwid->zoom != 1.0)
 				     || (winwid->w > winwid->im_w || winwid->h > winwid->im_h)
 				     || (winwid->has_rotated)))
 		feh_draw_checks(winwid);
 
-	if (!winwid->full_screen && opt.scale_down && ((winwid->w < winwid->im_w)
-						       || (winwid->h < winwid->im_h))) {
-		D(2, ("scaling down image\n"));
-
-		feh_calc_needed_zoom(&(winwid->zoom), winwid->im_w, winwid->im_h, winwid->w, winwid->h);
-		winwidget_resize(winwid, winwid->im_w * winwid->zoom, winwid->im_h * winwid->zoom);
-	}
-
 	if (resize && (winwid->full_screen || opt.geom_flags)) {
 		int smaller;	/* Is the image smaller than screen? */
 		int max_w = 0, max_h = 0;
@@ -380,7 +418,7 @@ void winwidget_render_image(winwidget winwid, int resize, int alias)
 			}
 		}
 
-		D(4, ("Calculating for fullscreen/fixed geom render\n"));
+		D(("Calculating for fullscreen/fixed geom render\n"));
 		smaller = ((winwid->im_w < max_w)
 			   && (winwid->im_h < max_h));
 
@@ -479,11 +517,10 @@ void winwidget_render_image(winwidget winwid, int resize, int alias)
 	sw = lround(dw / winwid->zoom);
 	sh = lround(dh / winwid->zoom);
 
-	D(5,
-	  ("sx: %d sy: %d sw: %d sh: %d dx: %d dy: %d dw: %d dh: %d zoom: %f\n",
+	D(("sx: %d sy: %d sw: %d sh: %d dx: %d dy: %d dw: %d dh: %d zoom: %f\n",
 	   sx, sy, sw, sh, dx, dy, dw, dh, winwid->zoom));
 
-	D(5, ("winwidget_render(): winwid->im_angle = %f\n", winwid->im_angle));
+	D(("winwidget_render(): winwid->im_angle = %f\n", winwid->im_angle));
 	if (winwid->has_rotated)
 		gib_imlib_render_image_part_on_drawable_at_size_with_rotation
 		    (winwid->bg_pmap, winwid->im, sx, sy, sw, sh, dx, dy, dw, dh, winwid->im_angle, 1, 1, alias);
@@ -494,28 +531,19 @@ void winwidget_render_image(winwidget winwid, int resize, int alias)
 								sh, dx, dy,
 								dw, dh, 1,
 								gib_imlib_image_has_alpha(winwid->im), alias);
-	if (opt.caption_path) {
-		/* cache bg pixmap. during caption entry, multiple redraws are done
-		 * because the caption overlay changes - the image doesn't though, so re-
-		 * rendering that is a waste of time */
-		if (winwid->caption_entry) {
-			GC gc;
-			if (winwid->bg_pmap_cache)
-				XFreePixmap(disp, winwid->bg_pmap_cache);
-			winwid->bg_pmap_cache = XCreatePixmap(disp, winwid->win, winwid->w, winwid->h, depth);
-			gc = XCreateGC(disp, winwid->win, 0, NULL);
-			XCopyArea(disp, winwid->bg_pmap, winwid->bg_pmap_cache, gc, 0, 0, winwid->w, winwid->h, 0, 0);
-			XFreeGC(disp, gc);
-		}
-		feh_draw_caption(winwid);
-	}
 
-	if (opt.draw_filename)
-		feh_draw_filename(winwid);
-	if (opt.draw_actions)
-		feh_draw_actions(winwid);
-	if ((opt.mode == MODE_ZOOM) && !alias)
+	if (opt.mode == MODE_NORMAL) {
+		if (opt.caption_path)
+			winwidget_update_caption(winwid);
+		if (opt.draw_filename)
+			feh_draw_filename(winwid);
+		if (opt.draw_actions)
+			feh_draw_actions(winwid);
+		if (opt.info_cmd)
+			feh_draw_info(winwid);
+	} else if ((opt.mode == MODE_ZOOM) && !alias)
 		feh_draw_zoom(winwid);
+
 	XSetWindowBackgroundPixmap(disp, winwid->win, winwid->bg_pmap);
 	XClearWindow(disp, winwid->win);
 	return;
@@ -536,6 +564,8 @@ void winwidget_render_image_cached(winwidget winwid)
 		feh_draw_filename(winwid);
 	if (opt.draw_actions)
 		feh_draw_actions(winwid);
+	if (opt.info_cmd)
+		feh_draw_info(winwid);
 	XSetWindowBackgroundPixmap(disp, winwid->win, winwid->bg_pmap);
 	XClearWindow(disp, winwid->win);
 }
@@ -676,7 +706,7 @@ winwidget winwidget_get_first_window_of_type(unsigned int type)
 
 int winwidget_loadimage(winwidget winwid, feh_file * file)
 {
-	D(4, ("filename %s\n", file->filename));
+	D(("filename %s\n", file->filename));
 	return(feh_load_image(&(winwid->im), file));
 }
 
@@ -690,9 +720,9 @@ void winwidget_show(winwidget winwid)
 		if (opt.full_screen)
 			XMoveWindow(disp, winwid->win, 0, 0);
 		/* wait for the window to map */
-		D(4, ("Waiting for window to map\n"));
+		D(("Waiting for window to map\n"));
 		XMaskEvent(disp, StructureNotifyMask, &ev);
-		D(4, ("Window mapped\n"));
+		D(("Window mapped\n"));
 		winwid->visible = 1;
 	}
 	return;
@@ -708,7 +738,7 @@ void winwidget_move(winwidget winwid, int x, int y)
 		XMoveWindow(disp, winwid->win, winwid->x, winwid->y);
 		XFlush(disp);
 	} else {
-		D(4, ("No move actually needed\n"));
+		D(("No move actually needed\n"));
 	}
 	return;
 }
@@ -724,7 +754,7 @@ void winwidget_resize(winwidget winwid, int w, int h)
 		return;
 	}
 	if (winwid && ((winwid->w != w) || (winwid->h != h))) {
-		D(4, ("Really doing a resize\n"));
+		D(("Really doing a resize\n"));
 		/* winwidget_clear_background(winwid); */
 		if (opt.screen_clip) {
 			winwid->w = (w > scr->width) ? scr->width : w;
@@ -758,11 +788,13 @@ void winwidget_resize(winwidget winwid, int w, int h)
 				}
 
 			}
+			if (getenv("XINERAMA_SCREEN"))
+				xinerama_screen = atoi(getenv("XINERAMA_SCREEN"));
 		}
 #endif				/* HAVE_LIBXINERAMA */
 
 	} else {
-		D(4, ("No resize actually needed\n"));
+		D(("No resize actually needed\n"));
 	}
 
 	return;
@@ -777,7 +809,7 @@ void winwidget_hide(winwidget winwid)
 
 static void winwidget_register(winwidget win)
 {
-	D(5, ("window %p\n", win));
+	D(("window %p\n", win));
 	window_num++;
 	if (windows)
 		windows = erealloc(windows, window_num * sizeof(winwidget));
